package com.isu.gaswellwatch.modbus.data.decode.impl;

import com.isu.gaswellwatch.modbus.data.ModbusMessage;
import com.isu.gaswellwatch.modbus.data.decode.DecodeHandler;
import com.isu.gaswellwatch.utils.ReverseComplementCodeUtils;
import org.springframework.stereotype.Component;

import java.util.Map;

/**
 * 有符号整数转换
 *
 * @author <a href="mailto:scwsl@foxmail.com">王仕龙</a>
 * 2024/11/25 16:24
 */
@Component(SignedNumberDecodeHandler.NAME + DecodeHandler.DECODE_NAME)
public class SignedNumberDecodeHandler implements DecodeHandler {
    public static final String NAME = "signedNumber";

    @Override
    public String decode(Map<String, Object> commandPointMap, String value) {
        int decimalNumber = Integer.parseInt(value, 16);
        if (decimalNumber == 0) {
            return String.valueOf(decimalNumber);
        }
        String binaryNumber = Integer.toBinaryString(decimalNumber);
        binaryNumber = ReverseComplementCodeUtils.binOriginalToReverse(binaryNumber);
        binaryNumber = ReverseComplementCodeUtils.binReverseToComplement(binaryNumber, "1");
        return ReverseComplementCodeUtils.binComplementToDec(binaryNumber);
    }

    @Override
    public void decode(Map<String, Object> commandPointMap, ModbusMessage.MessagePoint point) {
        point.setValue(this.decode(commandPointMap, point.getParseValue()));
    }

}
