package com.isu.gaswellwatch.service;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.IService;
import com.isu.gaswellwatch.dto.GasWellCreateRequest;
import com.isu.gaswellwatch.dto.GasWellEditRequest;
import com.isu.gaswellwatch.entity.GasWell;
import com.isu.gaswellwatch.vo.GasWellVO;

import java.util.Collection;
import java.util.List;

/**
 * 气井Service接口
 *
 * @author scwsl
 * @date 2024-11-17
 */
public interface GasWellService extends IService<GasWell> {
    /**
     * 查询气井
     *
     * @param id 气井主键
     * @return 气井
     */
    GasWellVO selectGasWellById(Long id);

    /**
     * 查询气井列表
     *
     * @param gasWell 气井
     * @return 气井集合
     */
    List<GasWellVO> selectGasWellList(GasWell gasWell);

    /**
     * 分页查询气井列表
     *
     * @return 气井
     */
    Page<GasWellVO> pageForQuery(Integer currentPage, Integer pageSize, String name, Long blockId);

    /**
     * 新增气井
     *
     * @param gasWellCreateRequest 气井
     * @return 结果
     */
    int insertGasWell(GasWellCreateRequest gasWellCreateRequest);

    /**
     * 修改气井
     *
     * @param gasWellEditRequest 气井
     * @return 结果
     */
    int updateGasWell(GasWellEditRequest gasWellEditRequest);

    /**
     * 删除气井信息
     *
     * @param id 气井主键
     * @return 结果
     */
    int deleteGasWellById(Long id);

    /**
     * 批量删除气井
     *
     * @param ids 需要删除的气井主键集合
     * @return 结果
     */
    int deleteGasWellByIds(Collection<Long> ids);

    /**
     * 绑定气井设备
     *
     * @param gasWellId 气井主键
     * @param deviceId  设备主键
     * @return 结果
     */
    void bindDevice(Long gasWellId, Long deviceId);

    void unbindDevice(Long id);
}
